@@ -25,6 +25,7 @@ import java.text.MessageFormat;
 import java.util.Collection;
 import java.util.Enumeration;
 import java.util.Iterator;
+import java.util.Arrays;
 
 /**
  * ANXB
@@ -33,7 +34,7 @@ import java.util.Iterator;
  * ĘAȂǁAlXȕ@ŕA邽߂̃\bhpӂB
  *
  * @author  V. 
- * @version $Revision: 1.2 $, $Date: 2007/02/15 15:28:05 $
+ * @version $Revision: 1.3 $, $Date: 2007/05/27 16:13:17 $
  */
 public class StringConcatenator
 {
@@ -59,7 +60,7 @@ public class StringConcatenator
     assert (strings != null) : "@param:strings is null.";
     assert (delimiter != null) : "@param:delimiter is null.";
 
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     if (strings.length > 0) {
       buf.append(strings[0]);
       for (int i=1; i<strings.length; i++) {
@@ -86,7 +87,7 @@ public class StringConcatenator
     assert (enm != null) : "@param:enm is null.";
     assert (delimiter != null) : "@param:delimiter is null.";
 
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     if (enm.hasMoreElements()) {
       buf.append(enm.nextElement());
       while (enm.hasMoreElements()) {
@@ -113,7 +114,7 @@ public class StringConcatenator
     assert (coll != null) : "@param:coll is null.";
     assert (delimiter != null) : "@param;delimiter is null.";
 
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     Iterator<String> it = coll.iterator();
     if (it.hasNext()) {
       buf.append(it.next());
@@ -134,12 +135,39 @@ public class StringConcatenator
    * @param  count JԂ񐔁B
    * @return A̕B
    * @throws AssertionError JԂ񐔂̏ꍇifobO[ĥ݁jB
+   * @deprecated <code>char</code>ϐ̎gp邽ߔp~B{@link
+   *   #repeat(String,int)}gpĉB
    */
+  @Deprecated
   public static String repeat(char repeated, int count)
   {
      assert (count >= 0) : "@param:count is negative.";
 
-     StringBuffer buf = new StringBuffer();
+     StringBuilder buf = new StringBuilder();
+     for (int i=0; i<count; i++) {
+       buf.append(repeated);
+     }
+     return buf.toString();
+  }
+
+  /**
+   * w肳ꂽAw񐔕JԂAB
+   * <br>
+   * z̗vfɃk܂܂Ăꍇ́A̗vf<tt>"null"</tt>Ƃ
+   * AB
+   *
+   * @param  repeated JԂ̑ΏەB
+   * @param  count JԂ񐔁B
+   * @return A̕B
+   * @throws AssertionError Ώە񂪃k̏ꍇA͌JԂ񐔂̏ꍇ
+   *          ifobO[ĥ݁jB
+   */
+  public static String repeat(String repeated, int count)
+  {
+     assert (repeated != null) : "@param:repeated is null.";
+     assert (count >= 0) : "@param:count is negative.";
+
+     StringBuilder buf = new StringBuilder();
      for (int i=0; i<count; i++) {
        buf.append(repeated);
      }
@@ -162,7 +190,7 @@ public class StringConcatenator
     assert (delimiter != null) : "@param:delimiter is null.";
     assert (count >= 0) : "@param:count is negative.";
 
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     if (count > 0) {
       buf.append(repeated);
       for (int i=1; i<count; i++) {
@@ -194,7 +222,7 @@ public class StringConcatenator
     if (fmt instanceof MessageFormat) {
       MessageFormat mf = (MessageFormat) fmt;
       Object[] args = new Object[1];
-      StringBuffer sb = new StringBuffer();
+      StringBuilder sb = new StringBuilder();
       if (objs.length > 0) {
         args[0] = objs[0];
         sb.append(MessageFormat.format(mf.toPattern(), args));
@@ -206,7 +234,7 @@ public class StringConcatenator
       return sb.toString();
     }
     else {
-      StringBuffer sb = new StringBuffer();
+      StringBuilder sb = new StringBuilder();
       if (objs.length > 0) {
         sb.append(fmt.format(objs[0]));
         for (int i=1; i<objs.length; i++) {
@@ -239,7 +267,7 @@ public class StringConcatenator
     if (fmt instanceof MessageFormat) {
       MessageFormat mf = (MessageFormat) fmt;
       Object[] args = new Object[1];
-      StringBuffer sb = new StringBuffer();
+      StringBuilder sb = new StringBuilder();
       if (enm.hasMoreElements()) {
         args[0] = enm.nextElement();
         sb.append(MessageFormat.format(mf.toPattern(), args));
@@ -251,7 +279,7 @@ public class StringConcatenator
       return sb.toString();
     }
     else {
-      StringBuffer sb = new StringBuffer();
+      StringBuilder sb = new StringBuilder();
       if (enm.hasMoreElements()) {
         sb.append(fmt.format(enm.nextElement()));
         while (enm.hasMoreElements()) {
@@ -284,7 +312,7 @@ public class StringConcatenator
     if (fmt instanceof MessageFormat) {
       MessageFormat mf = (MessageFormat) fmt;
       Object[] args = new Object[1];
-      StringBuffer sb = new StringBuffer();
+      StringBuilder sb = new StringBuilder();
       Iterator it = coll.iterator();
       if (it.hasNext()) {
         args[0] = it.next();
@@ -297,7 +325,7 @@ public class StringConcatenator
       return sb.toString();
     }
     else {
-      StringBuffer sb = new StringBuffer();
+      StringBuilder sb = new StringBuilder();
       Iterator it = coll.iterator();
       if (it.hasNext()) {
         sb.append(fmt.format(it.next()));
@@ -309,6 +337,40 @@ public class StringConcatenator
     }
   }
 
+  /**
+   * w肳ꂽ̔zA؂蕶gĘAB
+   * <br>
+   * ؂蕶񂪕񒆂Ɍꍇ́ÃGXP[v̒O
+   * }B
+   * <br>
+   * z̗vfɃk܂܂Ăꍇ́A̗vf<tt>"null"</tt>Ƃ
+   * AB
+   *
+   * @param  strs ̔zB
+   * @param  delim ؂蕶B
+   * @param  escape GXP[vB
+   * @return A̕B
+   * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   */
+  public static String concatenate(String[] strs, String delim, String escape)
+  {
+    assert (strs != null) : "@param:strs is null.";
+    assert (delim != null) : "@param:delim is null.";
+    assert (escape != null) : "@param:escape is null.";
+
+    Collection<String> spL = Arrays.asList(delim);
+
+    StringBuilder buf = new StringBuilder();
+    if (strs.length > 0) {
+      buf.append(StringConverter.toWriteString(strs[0], escape, spL));
+      for (int i=1; i<strs.length; i++) {
+        buf.append(delim);
+        buf.append(StringConverter.toWriteString(strs[i], escape, spL));
+      }
+    }
+    return buf.toString();
+  }
+
   /**
    * w肳ꂽ̔zA؂蕶gĘAB
    * <br>
@@ -323,15 +385,18 @@ public class StringConcatenator
    * @param  escape GXP[vB
    * @return A̕B
    * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   * @deprecated <code>char</code>ϐ̎gp邽ߔp~B{@link
+   *   #concatenate(String[],String,String)}gpĉB
    */
+  @Deprecated
   public static String concatenate(String[] strs, char delim, char escape)
   {
     assert (strs != null) : "@param:strs is null.";
 
-    StringBuffer specChars = new StringBuffer();
+    StringBuilder specChars = new StringBuilder();
     specChars.append(delim);
 
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     if (strs.length > 0) {
       buf.append(StringConverter.toWriteString(strs[0], escape, specChars));
       for (int i=1; i<strs.length; i++) {
@@ -353,16 +418,19 @@ public class StringConcatenator
    * @param  esc GXP[vB
    * @return A̕B
    * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   * @deprecated <code>char</code>ϐ̎gp邽ߔp~B{@link
+   *   #concatenate(java.util.Enumeration,String,String)}gpĉB
    */
+  @Deprecated
   public static String concatenate(
     Enumeration<String> enm, char delim, char esc)
   {
     assert (enm != null) : "@param:enm is null.";
 
-    StringBuffer spe = new StringBuffer();
+    StringBuilder spe = new StringBuilder();
     spe.append(delim);
     
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     if (enm.hasMoreElements()) {
       buf.append(StringConverter.toWriteString(enm.nextElement(), esc, spe));
       while (enm.hasMoreElements()) {
@@ -373,6 +441,38 @@ public class StringConcatenator
     return buf.toString();
   }
 
+  /**
+   * w肳ꂽ񋓃IuWFNg̗vfA؂蕶gĘAB
+   * <br>
+   * ؂蕶񂪕񒆂Ɍꍇ́ÃGXP[v̒O
+   * }B
+   *
+   * @param  enm 񋓃IuWFNgB
+   * @param  delim ؂蕶B
+   * @param  esc GXP[vB
+   * @return A̕B
+   * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   */
+  public static String concatenate(
+    Enumeration<String> enm, String delim, String esc)
+  {
+    assert (enm != null) : "@param:enm is null.";
+    assert (delim != null) : "@param:delim is null.";
+    assert (esc != null) : "@param:esc is null.";
+
+    Collection<String> spL = Arrays.asList(delim);
+    
+    StringBuilder buf = new StringBuilder();
+    if (enm.hasMoreElements()) {
+      buf.append(StringConverter.toWriteString(enm.nextElement(), esc, spL));
+      while (enm.hasMoreElements()) {
+        buf.append(delim);
+        buf.append(StringConverter.toWriteString(enm.nextElement(), esc, spL));
+      }
+    }
+    return buf.toString();
+  }
+
   /**
    * w肳ꂽRNVIuWFNg̗vfA؂蕶g
    * AB
@@ -385,16 +485,19 @@ public class StringConcatenator
    * @param  esc GXP[vB
    * @return A̕B
    * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   * @deprecated <code>char</code>ϐ̎gp邽ߔp~B{@link
+   *   #concatenate(java.util.Collection,String,String)}gpĉB
    */
+  @Deprecated
   public static String concatenate(
     Collection<String> coll, char delim, char esc)
   {
     assert (coll != null) : "@param:coll is null.";
 
-    StringBuffer spe = new StringBuffer();
+    StringBuilder spe = new StringBuilder();
     spe.append(delim);
 
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     Iterator<String> it = coll.iterator();
     if (it.hasNext()) {
       buf.append(StringConverter.toWriteString(it.next(), esc, spe));
@@ -406,6 +509,40 @@ public class StringConcatenator
     return buf.toString();
   }
 
+  /**
+   * w肳ꂽRNVIuWFNg̗vfA؂蕶g
+   * AB
+   * <br>
+   * ؂蕶񂪕񒆂Ɍꍇ́ÃGXP[v̒O
+   * }B
+   *
+   * @param  coll RNVIuWFNgB
+   * @param  delim ؂蕶B
+   * @param  esc GXP[vB
+   * @return A̕B
+   * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   */
+  public static String concatenate(
+    Collection<String> coll, String delim, String esc)
+  {
+    assert (coll != null) : "@param:coll is null.";
+    assert (delim != null) : "@param:delim is null.";
+    assert (esc != null) : "@param:esc is null.";
+
+    Collection<String> spL = Arrays.asList(delim);
+
+    StringBuilder buf = new StringBuilder();
+    Iterator<String> it = coll.iterator();
+    if (it.hasNext()) {
+      buf.append(StringConverter.toWriteString(it.next(), esc, spL));
+      while (it.hasNext()) {
+        buf.append(delim);
+        buf.append(StringConverter.toWriteString(it.next(), esc, spL));
+      }
+    }
+    return buf.toString();
+  }
+
   /**
    * w肳ꂽ̔zAʂň͂݁A؂蕶gĘAB
    * <br>
@@ -419,18 +556,21 @@ public class StringConcatenator
    * @param  escape GXP[vB
    * @return A̕B
    * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   * @deprecated <code>char</code>ϐ̎gp邽ߔp~B{@link
+   *   #concatenate(String[],String,String,String,String)}gpĉB
    */
+  @Deprecated
   public static String concatenate(String[] strs, char delim,
     char openPar, char closePar, char escape)
   {
     assert (strs != null) : "@param:strs is null.";
 
-    StringBuffer specChars = new StringBuffer();
+    StringBuilder specChars = new StringBuilder();
     specChars.append(delim);
     specChars.append(openPar);
     specChars.append(closePar);
 
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     if (strs.length > 0) {
       buf.append(openPar);
       buf.append(StringConverter.toWriteString(strs[0], escape, specChars));
@@ -445,6 +585,46 @@ public class StringConcatenator
     return buf.toString();
   }
 
+  /**
+   * w肳ꂽ̔zAʂň͂݁A؂蕶gĘAB
+   * <br>
+   * ؂蕶⊇ʂ񒆂Ɍꍇ́ÃGXP[v
+   * Oɑ}B
+   *
+   * @param  strs ̔zB
+   * @param  delim ؂蕶B
+   * @param  openPar JʁB
+   * @param  closePar ʁB
+   * @param  escape GXP[vB
+   * @return A̕B
+   * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   */
+  public static String concatenate(String[] strs, String delim,
+    String openPar, String closePar, String escape)
+  {
+    assert (strs != null) : "@param:strs is null.";
+    assert (delim != null) : "@param:delim is null.";
+    assert (openPar != null) : "@param:openPar is null.";
+    assert (closePar != null) : "@param:closePar is null.";
+    assert (escape != null) : "@param:escape is null.";
+
+    Collection<String> spL = Arrays.asList(delim, openPar, closePar);
+
+    StringBuilder buf = new StringBuilder();
+    if (strs.length > 0) {
+      buf.append(openPar);
+      buf.append(StringConverter.toWriteString(strs[0], escape, spL));
+      buf.append(closePar);
+      for (int i=1; i<strs.length; i++) {
+        buf.append(delim);
+        buf.append(openPar);
+        buf.append(StringConverter.toWriteString(strs[i], escape, spL));
+        buf.append(closePar);
+      }
+    }
+    return buf.toString();
+  }
+
   /**
    * w肳ꂽ񋓃IuWFNg̗vfAʂň͂݁A؂蕶
    * gĘAB
@@ -459,18 +639,22 @@ public class StringConcatenator
    * @param  escape GXP[vB
    * @return A̕B
    * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   * @deprecated <code>char</code>ϐ̎gp邽ߔp~B{@link
+   *   #concatenate(java.util.Enumeration,String,String,String,String)}
+   *   gpĉB
    */
+  @Deprecated
   public static String concatenate(Enumeration<String> enm, char delim,
     char openPar, char closePar, char escape)
   {
     assert (enm != null) : "@param:enm is null.";
 
-    StringBuffer specChars = new StringBuffer();
+    StringBuilder specChars = new StringBuilder();
     specChars.append(delim);
     specChars.append(openPar);
     specChars.append(closePar);
 
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     if (enm.hasMoreElements()) {
       buf.append(openPar);
       buf.append(StringConverter.toWriteString(
@@ -487,6 +671,47 @@ public class StringConcatenator
     return buf.toString();
   }
 
+  /**
+   * w肳ꂽ񋓃IuWFNg̗vfAʂň͂݁A؂蕶
+   * gĘAB
+   * <br>
+   * ؂蕶⊇ʂ񒆂Ɍꍇ́ÃGXP[v
+   * Oɑ}B
+   *
+   * @param  enm 񋓃IuWFNgB
+   * @param  delim ؂蕶B
+   * @param  openPar JʁB
+   * @param  closePar ʁB
+   * @param  escape GXP[vB
+   * @return A̕B
+   * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   */
+  public static String concatenate(Enumeration<String> enm, String delim,
+    String openPar, String closePar, String escape)
+  {
+    assert (enm != null) : "@param:enm is null.";
+    assert (delim != null) : "@param:delim is null.";
+    assert (openPar != null) : "@param:openPar is null.";
+    assert (closePar != null) : "@param:closePar is null.";
+    assert (escape != null) : "@param:escape is null.";
+
+    Collection<String> spL = Arrays.asList(delim, openPar, closePar);
+
+    StringBuilder buf = new StringBuilder();
+    if (enm.hasMoreElements()) {
+      buf.append(openPar);
+      buf.append(StringConverter.toWriteString(enm.nextElement(), escape, spL));
+      buf.append(closePar);
+      while (enm.hasMoreElements()) {
+        buf.append(delim);
+        buf.append(openPar);
+        buf.append(StringConverter.toWriteString(enm.nextElement(),escape,spL));
+        buf.append(closePar);
+      }
+    }
+    return buf.toString();
+  }
+
   /**
    * w肳ꂽRNVIuWFNg̗vfAʂň͂݁A؂蕶
    * gĘAB
@@ -501,18 +726,22 @@ public class StringConcatenator
    * @param  escape GXP[vB
    * @return A̕B
    * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   * @deprecated <code>char</code>ϐ̎gp邽ߔp~B{@link
+   *   #concatenate(java.util.Collection,String,String,String,String)}gp
+   *   ĉB
    */
+  @Deprecated
   public static String concatenate(Collection<String> coll, char delim,
     char openPar, char closePar, char escape)
   {
     assert (coll != null) : "@param:coll is null.";
 
-    StringBuffer specChars = new StringBuffer();
+    StringBuilder specChars = new StringBuilder();
     specChars.append(delim);
     specChars.append(openPar);
     specChars.append(closePar);
 
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
     Iterator<String> it = coll.iterator();
     if (it.hasNext()) {
       buf.append(openPar);
@@ -527,4 +756,46 @@ public class StringConcatenator
     }
     return buf.toString();
   }
+
+  /**
+   * w肳ꂽRNVIuWFNg̗vfAʂň͂݁A
+   * ؂蕶gĘAB
+   * <br>
+   * ؂蕶⊇ʂ񒆂Ɍꍇ́ÃGXP[v
+   * Oɑ}B
+   *
+   * @param  coll RNVIuWFNgB
+   * @param  delim ؂蕶B
+   * @param  openPar JʁB
+   * @param  closePar ʁB
+   * @param  escape GXP[vB
+   * @return A̕B
+   * @throws AssertionError k̏ꍇifobO[ĥ݁jB
+   */
+  public static String concatenate(Collection<String> coll, String delim,
+    String openPar, String closePar, String escape)
+  {
+    assert (coll != null) : "@param:coll is null.";
+    assert (delim != null) : "@param:delim is null.";
+    assert (openPar != null) : "@param:openPar is null.";
+    assert (closePar != null) : "@param:closePar is null.";
+    assert (escape != null) : "@param:escape is null.";
+
+    Collection<String> spL = Arrays.asList(delim, openPar, closePar);
+
+    StringBuilder buf = new StringBuilder();
+    Iterator<String> it = coll.iterator();
+    if (it.hasNext()) {
+      buf.append(openPar);
+      buf.append(StringConverter.toWriteString(it.next(), escape, spL));
+      buf.append(closePar);
+      while (it.hasNext()) {
+        buf.append(delim);
+        buf.append(openPar);
+        buf.append(StringConverter.toWriteString(it.next(), escape, spL));
+        buf.append(closePar);
+      }
+    }
+    return buf.toString();
+  }
 }
